@@ -13,7 +13,7 @@ import requests
 from .mongo_tools import clean_json
 from .data_utils import to_dicts
 
-__version__ = "0.1.18"
+__version__ = "0.1.20"
 
 
 def logged_user(logger=logger):
@@ -33,8 +33,19 @@ def logged_user(logger=logger):
     return logging_user_wrapper
 
 
-def parse_float(value: str):
-    return float(value.replace(",", ""))
+def parse_float(value: str) -> float:
+    value = value.strip()
+    if value == "-":
+        return 0.0
+
+    return float(value.replace(",", "").replace("$", ""))
+
+
+def parse_int(value: str):
+    float_value = parse_float(value)
+    if not float_value.is_integer():
+        raise ValueError(f"{value} is not an integer")
+    return int(float_value)
 
 
 def now_utc():
